@@ -9,10 +9,14 @@ from core_main_app.components.data.models import Data
 class EditDataForm(DocumentForm):
     """ EditDataForm
     """
-    title = forms.CharField(label='Title',
-                            widget=forms.TextInput(attrs={'class': 'form-control',
-                                                          'placeholder': 'Type the new title'}))
+
+    title = forms.CharField(
+        label="Title",
+        widget=forms.TextInput(
+            attrs={"class": "form-control", "placeholder": "Type the new title"}
+        ),
+    )
 
     class Meta(object):
         document = Data
-        fields = ['title']
+        fields = ["title"]
